package com.datacloudsec.scan.service.impl;

import com.datacloudsec.annotations.Transactional;
import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.dao.BaselineMapper;
import com.datacloudsec.scan.dao.BlineBugMapper;
import com.datacloudsec.scan.dao.DeviceGroupMapper;
import com.datacloudsec.scan.dao.DeviceMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.LogMapper;
import com.datacloudsec.scan.entity.LicCmp;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.entity.User;
import com.datacloudsec.scan.service.IBaseline;
import com.datacloudsec.scan.service.IDb;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.tasks.InitSystemTask;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.utils.ComonZipUtil;
import com.datacloudsec.utils.DataRule;
import com.datacloudsec.utils.EncodingDetect;
import com.datacloudsec.utils.IPUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.JsonUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.SerializeUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import java.io.File;
import java.io.FileOutputStream;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.collections4.MapUtils;
import org.apache.commons.io.FileUtils;
import org.apache.commons.io.IOUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_service_impl.jar:com/datacloudsec/scan/service/impl/BaselineService.class */
public class BaselineService extends TaskBaseService implements IBaseline {
    private Logger LOG = Logger.getLogger(BaselineService.class);
    private BaselineMapper baselineMapper = (BaselineMapper) InstanceUtil.newDaoInstance(BaselineMapper.class);
    private DeviceMapper deviceMapper = (DeviceMapper) InstanceUtil.newDaoInstance(DeviceMapper.class);
    private DeviceGroupMapper deviceGroupMapper = (DeviceGroupMapper) InstanceUtil.newDaoInstance(DeviceGroupMapper.class);
    private BlineBugMapper blineBugMapper = (BlineBugMapper) InstanceUtil.newDaoInstance(BlineBugMapper.class);
    private IEngine engine = (IEngine) InstanceUtil.newServiceInstance(EngineService.class);
    private LogMapper logMapper = (LogMapper) InstanceUtil.newDaoInstance(LogMapper.class);

    public void delete(HttpSession session, Integer id, Integer version) throws Exception {
        delTask(session, id, version);
    }

    public Integer insert(HttpSession session, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, String btype, String confContent, String warningType, Integer val1, Integer val3, String ftpReportType) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        if (!cmp.contains("bline")) {
            throw new UEException("基线配置核查任务未授权");
        }
        LicCmp licCmp = getLicCp(cmp, "bline");
        if (InitSystemTask.licenseApp.valudate(licCmp.getAuthDay()) != 0) {
            throw new UEException("基线配置核查任务授权已过期");
        }
        User user = null;
        try {
            user = (User) session.getAttribute("userInfo");
            Integer count = this.baselineMapper.getTaskCountByName(name, 2, Integer.valueOf(user == null ? 1 : user.getId().intValue()), (Integer) null);
            if (count != null && count.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        } catch (Exception e) {
            Integer count2 = this.baselineMapper.getTcountForOthers(name, 2, (Integer) null);
            if (count2 != null && count2.intValue() > 0) {
                throw new UEException("任务名称已存在！");
            }
        }
        Integer taskid = add(null, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, devList, periodTime, emailcheck, smscheck, null, 2, btype, confContent, warningType, val1, val3, ftpReportType, session);
        if (type.intValue() == 1) {
            List<Map<String, Object>> taskWebList = this.baselineMapper.getTaskDevByTid(taskid);
            boolean bl = true;
            for (Map<String, Object> map : taskWebList) {
                Integer devid = ObjectUtil.getInt(map.get("id"));
                try {
                    start(devid);
                } catch (Exception e2) {
                    bl = false;
                    this.LOG.error("立即扫描异常URL（" + map.get("url") + "）：", e2);
                }
            }
            if (bl) {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描基线配置核查任务", "", 1, "扫描成功");
            } else {
                this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描基线配置核查任务", "", 2, "扫描失败");
            }
        }
        startTimer(taskid, type, periodTime, alarmType, alarmMethod, alarmTime);
        return taskid;
    }

    private Integer add(Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String devList, String periodTime, String emailcheck, String smscheck, Integer version, Integer taskType, String btype, String confContent, String warningType, Integer val1, Integer val3, String ftpReportType, HttpSession session) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "bline");
        int maxdevice = licCmp.getMaxdevice();
        User user = (User) session.getAttribute("userInfo");
        String rule = DataRule.getRuleWhere(session, "t_task");
        Task task = new Task();
        task.setName(name);
        if (id != null) {
            task.setId(id);
        }
        task.setDesct(desct);
        task.setType(type);
        task.setAlarmMethod(alarmMethod);
        task.setAlarmType(alarmType);
        task.setAlarmTime(alarmTime);
        task.setMailAddr(emailcheck);
        task.setSmsAddr(smscheck);
        task.setPeriodTime(periodTime);
        task.setUid(Integer.valueOf(user == null ? 1 : user.getId().intValue()));
        task.setTaskType(taskType);
        task.setVersion(version);
        task.setBtype(StringUtils.isBlank(btype) ? "默认" : btype);
        task.setRule(rule);
        task.setConfContent(confContent);
        task.setWarningType(warningType);
        task.setVal1(val1);
        task.setVal2(new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(new Date()));
        task.setVal3(ObjectUtil.getString(val3, ReportService.REPORT_STATE_FAILED));
        task.setFtpReportType(ftpReportType);
        if (id != null) {
            task.setId(id);
        }
        if (id == null) {
            List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
            int devIpCount = 0;
            for (Map<String, Object> devMap : devListMap) {
                if (StringUtils.isNotBlank(ObjectUtil.getString(devMap.get("merge"), ""))) {
                    List<Map<String, Object>> taskDevices = this.baselineMapper.getTaskDevByTid(ObjectUtil.getInt(devMap.get("id")));
                    if (CollectionUtils.isNotEmpty(taskDevices)) {
                        devIpCount += taskDevices.size();
                    }
                } else {
                    Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(ObjectUtil.getString(devMap.get("id"), "").split("\\|")[0]));
                    if (map != null) {
                        String ip = ObjectUtil.getString(map.get("ip"), "");
                        if (user != null && StringUtils.isNotBlank(user.getIps()) && !IPUtil.ipVaild(ip, user.getIps())) {
                            throw new UEException("IP【" + ip + "】不在扫描范围内，可联系管理员授权扫描此IP");
                        }
                        devIpCount++;
                    } else {
                        continue;
                    }
                }
            }
            if (maxdevice > 0 && this.baselineMapper.getCountByType("3|4|5|6|7|8|11") + devIpCount > maxdevice) {
                throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
            }
            this.baselineMapper.insert(task);
            for (Map<String, Object> devMap2 : devListMap) {
                if (StringUtils.isNotBlank(ObjectUtil.getString(devMap2.get("copy"), ""))) {
                    Integer devid = ObjectUtil.getInt(devMap2.get("id"));
                    Map<String, Object> map2 = this.baselineMapper.getTaskDevById(devid);
                    map2.put("taskId", task.getId());
                    this.baselineMapper.insertTaskDevice(map2);
                } else if (StringUtils.isNotBlank(ObjectUtil.getString(devMap2.get("merge"), ""))) {
                    for (Map<String, Object> map3 : this.baselineMapper.getTaskDevByTid(ObjectUtil.getInt(devMap2.get("id")))) {
                        map3.put("taskId", task.getId());
                        this.baselineMapper.insertTaskDevice(map3);
                    }
                } else {
                    String[] idarr = ObjectUtil.getString(devMap2.get("id"), "").split("\\|");
                    Map<String, Object> map4 = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
                    if (map4 != null) {
                        Map<String, Object> devGroup = this.deviceGroupMapper.getDevGroupById(ObjectUtil.getInt(map4.get("dgid")));
                        if (MapUtils.isNotEmpty(devGroup)) {
                            map4.put("devgroup", ObjectUtil.getString(devGroup.get("name"), ""));
                        }
                        map4.put("taskId", task.getId());
                        Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map4.get("confContent"), ""), HashMap.class);
                        String auth = ObjectUtil.getString(map4.get("authContent"), "");
                        Map<String, Object> authConfMap = null;
                        if (!"".equals(auth)) {
                            authConfMap = (Map) JsonUtil.MAPPER.readValue(auth, HashMap.class);
                        }
                        Map<String, Object> confMap = new HashMap<>();
                        String typeKey = idarr[1];
                        if (ReportService.REPORT_STATE_FAILED.equals(typeKey) || "3".equals(typeKey)) {
                            List<Map<String, Object>> confListMap = (List) confContentMap.get(typeKey);
                            Iterator<Map<String, Object>> it = confListMap.iterator();
                            while (true) {
                                if (!it.hasNext()) {
                                    break;
                                }
                                Map<String, Object> conf = it.next();
                                if (conf.containsKey("db")) {
                                    if (idarr[2].equals(ObjectUtil.getString(conf.get("db"), ""))) {
                                        confMap.putAll(conf);
                                        break;
                                    }
                                } else if (idarr[2].equals(ObjectUtil.getString(conf.get("linuxV"), ""))) {
                                    confMap.putAll(conf);
                                    break;
                                }
                            }
                        } else {
                            confMap.putAll((Map) confContentMap.get(typeKey));
                        }
                        if (!ReportService.REPORT_STATE_FAILED.equals(typeKey) && authConfMap != null) {
                            confMap.putAll(authConfMap);
                        }
                        map4.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap));
                        if (ReportService.REPORT_STATE_READY.equals(typeKey)) {
                            typeKey = "7";
                        } else if (ReportService.REPORT_STATE_FAILED.equals(typeKey)) {
                            typeKey = "8";
                        }
                        map4.put("type", typeKey);
                        map4.put("name", ObjectUtil.getString(devMap2.get("name"), ""));
                        this.baselineMapper.insertTaskDevice(map4);
                        String imp = ObjectUtil.getString(devMap2.get("imp"), "");
                        if (StringUtils.isNotBlank(imp)) {
                            this.deviceMapper.delete(ObjectUtil.getInt(idarr[0]), 0, DataRule.getRuleWhere(session, "t_device"));
                        }
                    }
                }
            }
        } else {
            Integer rcount = this.baselineMapper.update(task);
            if (rcount != null && rcount.intValue() == 0) {
                throw new UEException("数据已被修改或删除，请刷新页面或返回");
            }
        }
        if (user != null) {
            if (StringUtils.isNotBlank(mailAddr)) {
                this.baselineMapper.delEmail(user.getId());
                String[] mail = mailAddr.split(",");
                for (String ml : mail) {
                    this.baselineMapper.insertEmail(ml, user.getId());
                }
            }
            if (StringUtils.isNotBlank(smsAddr)) {
                this.baselineMapper.delPhone(user.getId());
                String[] sms = smsAddr.split(",");
                for (String s : sms) {
                    this.baselineMapper.insertPhone(s, user.getId());
                }
            }
        }
        return task.getId();
    }

    public void insertTaskDev(Map<String, Object> map) throws Exception {
        this.baselineMapper.insertTaskDevice(map);
    }

    public void update(HttpSession session, Integer id, String name, String desct, Integer type, String alarmMethod, Integer alarmType, String alarmTime, String mailAddr, String smsAddr, String periodTime, String emailcheck, String smscheck, Integer version, String btype, String confContent, String warningType, Integer val1, Integer val3, String ftpReportType) throws Exception {
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.baselineMapper.getTaskCountByName(name, 2, uid, id);
        if (count != null && count.intValue() > 0) {
            throw new UEException("任务名称已存在！");
        }
        add(id, name, desct, type, alarmMethod, alarmType, alarmTime, mailAddr, smsAddr, null, periodTime, emailcheck, smscheck, version, 2, btype, confContent, warningType, val1, val3, ftpReportType, session);
        stopTimer(session, id);
        if (alarmType.intValue() == 2 || type.intValue() == 2) {
            startTimer(id, type, periodTime, alarmType, alarmMethod, alarmTime);
        }
    }

    public void start(Integer devid) throws Exception {
        Map<String, Object> device = this.baselineMapper.getTaskDevById(devid);
        if (device == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        int status = ObjectUtil.getInt(device.get("status"), 1);
        if (status != 1) {
            SqlSession session = null;
            try {
                try {
                    session = MybatisUtil.sqlSessionFactory.openSession(true);
                    BlineBugMapper blineBugMapper = (BlineBugMapper) session.getMapper(BlineBugMapper.class);
                    BaselineMapper baselineMapper = (BaselineMapper) session.getMapper(BaselineMapper.class);
                    blineBugMapper.delResultByDevId2(devid);
                    blineBugMapper.delErr(devid);
                    Map<String, Object> dmap = new HashMap<>();
                    dmap.put("offset1", 0);
                    dmap.put("offset2", 0);
                    dmap.put("offset3", 0);
                    dmap.put("progress", 0);
                    dmap.put("devid", devid);
                    baselineMapper.updateTaskDevice(dmap);
                    session.commit();
                    if (session != null) {
                        session.close();
                    }
                    String config = ObjectUtil.getString(device.get("confContent"), "{}");
                    Map<String, String> taskOption = (Map) JsonUtil.MAPPER.readValue(config, new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.BaselineService.1
                    });
                    String filename = taskOption.get("sysCfg");
                    if (StringUtils.isNotBlank(filename)) {
                        File f = new File(Constant.COMMON_DIR, "device/" + filename);
                        taskOption.put("sysCfg", FileUtils.readFileToString(f, EncodingDetect.getJavaEncode(f)));
                    }
                    taskOption.put("ip", ObjectUtil.getString(device.get("ip"), ""));
                    Task task = this.baselineMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                    if (StringUtils.isNotBlank(task.getConfContent())) {
                        Map<String, String> taskConf = (Map) JsonUtil.MAPPER.readValue(task.getConfContent(), new TypeReference<Map<String, String>>() { // from class: com.datacloudsec.scan.service.impl.BaselineService.2
                        });
                        taskOption.putAll(taskConf);
                    }
                    SqlSession session2 = null;
                    try {
                        try {
                            SqlSession session22 = MybatisUtil.sqlSessionFactory.openSession(true);
                            EngineMapper engineMapper = (EngineMapper) session22.getMapper(EngineMapper.class);
                            String poliname = ObjectUtil.getString(taskOption.get("linuxV"), "");
                            if (StringUtils.isBlank(poliname)) {
                                poliname = (String) IDb.DB_SCAN_TYPE.get(ObjectUtil.getString(taskOption.get("db"), ""));
                                if (StringUtils.isBlank(poliname)) {
                                    poliname = ObjectUtil.getString(taskOption.get("assetType"), "");
                                }
                                if (StringUtils.isBlank(poliname)) {
                                    if (session22 != null) {
                                        session22.close();
                                        return;
                                    }
                                    return;
                                }
                            }
                            int scanCount = ObjectUtil.getInt(device.get("scanCount"), 0);
                            if (scanCount > 0) {
                                engineMapper.blineReplaceVuls2(devid, engineMapper.getBlinePoliByPoliName(poliname, task == null ? "默认" : task.getBtype()));
                            } else {
                                engineMapper.blineReplaceVuls(devid, engineMapper.getBlinePoliByPoliName(poliname, task == null ? "默认" : task.getBtype()));
                            }
                            session22.commit();
                            int devType = ObjectUtil.getInt(device.get("type"), -1);
                            if (devType == 8) {
                                Map<String, Object> taskwebmap = new HashMap<>();
                                taskwebmap.put("devid", devid);
                                taskwebmap.put("status", 1);
                                taskwebmap.put("scanCount", Integer.valueOf(scanCount + 1));
                                taskwebmap.put("startTime", new Date());
                                this.baselineMapper.updateTaskDevice(taskwebmap);
                                this.engine.blineDbScan(devid.intValue(), ObjectUtil.getString(device.get("ip"), ""), taskOption, Integer.valueOf(scanCount));
                                if (ObjectUtil.getInt(task.getAlarmType(), 0) == 1) {
                                    device.put("taskType", task.getTaskType());
                                    device.put("alarmType", task.getAlarmType());
                                    device.put("alarmMethod", task.getAlarmMethod());
                                    device.put("warningType", task.getWarningType());
                                    device.put("mailAddr", task.getMailAddr());
                                    device.put("smsAddr", task.getSmsAddr());
                                    device.put("dest", task.getDest());
                                    device.put("scanType", task.getType());
                                    AlermJob.alermDevice(device);
                                }
                            } else {
                                boolean checkWay = false;
                                if (devType == 7) {
                                    checkWay = "agent".equals(ObjectUtil.getString(taskOption.get("checkmed"), ""));
                                }
                                if (!checkWay) {
                                    IEngine.EngineResult eresult = this.engine.blineScan(devid.intValue(), ObjectUtil.getString(device.get("ip"), ""), taskOption);
                                    if (eresult != null) {
                                        Map<String, Object> taskwebmap2 = new HashMap<>();
                                        taskwebmap2.put("devid", devid);
                                        taskwebmap2.put("status", 1);
                                        taskwebmap2.put("scanCount", Integer.valueOf(scanCount + 1));
                                        taskwebmap2.put("startTime", new Date());
                                        taskwebmap2.put("engineId", eresult.getEngineId());
                                        taskwebmap2.put("localEid", Integer.valueOf(eresult.getLocalId()));
                                        this.baselineMapper.updateTaskDevice(taskwebmap2);
                                    } else {
                                        Map<String, Object> taskwebmap3 = new HashMap<>();
                                        taskwebmap3.put("devid", devid);
                                        taskwebmap3.put("status", 4);
                                        this.baselineMapper.updateTaskDevice(taskwebmap3);
                                    }
                                }
                            }
                            if (session22 != null) {
                                session22.close();
                            }
                        } catch (Exception e) {
                            session2.rollback();
                            Map<String, Object> emap = new HashMap<>();
                            emap.put("error", e instanceof UEException ? e.getMessage() : "扫描出错");
                            emap.put("status", 3);
                            emap.put("devid", devid);
                            this.baselineMapper.updateTaskDevice(emap);
                            this.LOG.error("", e);
                            if (0 != 0) {
                                session2.close();
                            }
                        }
                    } catch (Throwable th) {
                        if (0 != 0) {
                            session2.close();
                        }
                        throw th;
                    }
                } catch (Exception e2) {
                    session.rollback();
                    throw e2;
                }
            } catch (Throwable th2) {
                if (session != null) {
                    session.close();
                }
                throw th2;
            }
        }
    }

    public void startScanTask(Integer taskId) throws Exception {
        List<Map<String, Object>> taskDevList = this.blineBugMapper.getTaskDevByTid(taskId);
        if (taskDevList == null) {
            throw new UEException("此任务已被其它用户删除！");
        }
        for (Map<String, Object> dev : taskDevList) {
            if (1 != ObjectUtil.getInt(dev.get("status")).intValue()) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                try {
                    start(devid);
                } catch (Exception e) {
                    this.LOG.error("手动扫描出错", e);
                }
            }
        }
    }

    public void delDev(Integer devId) throws Exception {
        Map<String, Object> webMap = this.blineBugMapper.getTaskDevById(devId);
        String eid = ObjectUtil.getString(webMap.get("engineId"), "");
        if (StringUtils.isNotBlank(eid)) {
            this.engine.blineDelete(ObjectUtil.getInt(webMap.get("type"), -1), eid, ObjectUtil.getInt(webMap.get("localEid")).intValue());
        }
        SqlSession session = null;
        try {
            try {
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                BlineBugMapper blineBugMapper = (BlineBugMapper) session.getMapper(BlineBugMapper.class);
                BaselineMapper baselineMapper = (BaselineMapper) session.getMapper(BaselineMapper.class);
                blineBugMapper.delResultByDevId(devId);
                blineBugMapper.delErr(devId);
                blineBugMapper.clearStatistics(devId);
                baselineMapper.delTaskDevById(devId);
                session.commit();
                if (session != null) {
                    session.close();
                }
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                throw e;
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }

    public void addDev(HttpSession session, String devList, Integer taskId) throws Exception {
        Map<String, String> params = InitSystemTask.licenseApp.getLicenseLic().getParams();
        String cmp = ObjectUtil.getString(params.get("cmp"), "");
        LicCmp licCmp = getLicCp(cmp, "bline");
        int maxdevice = licCmp.getMaxdevice();
        List<Map<String, Object>> devListMap = (List) JsonUtil.MAPPER_ESCAPE_HTML.readValue(devList, ArrayList.class);
        int devIpCount = devListMap.size();
        if (maxdevice > 0 && this.baselineMapper.getCountByType("3|4|5|6|7|8|11") + devIpCount > maxdevice) {
            throw new UEException("当前资产数已达授权上限[" + maxdevice + "]");
        }
        List<Integer> devices = new ArrayList<>();
        for (Map<String, Object> webMap : devListMap) {
            String[] idarr = ObjectUtil.getString(webMap.get("id"), "").split("\\|");
            Map<String, Object> map = this.deviceMapper.getDevById(ObjectUtil.getInt(idarr[0]));
            if (map != null) {
                map.put("taskId", taskId);
                Map<String, Object> confContentMap = (Map) JsonUtil.MAPPER.readValue(ObjectUtil.getString(map.get("confContent"), ""), HashMap.class);
                String auth = ObjectUtil.getString(map.get("authContent"), "");
                Map<String, Object> authConfMap = null;
                if (!"".equals(auth)) {
                    authConfMap = (Map) JsonUtil.MAPPER.readValue(auth, HashMap.class);
                }
                Map<String, Object> confMap = new HashMap<>();
                String typeKey = idarr[1];
                if (ReportService.REPORT_STATE_FAILED.equals(typeKey) || "3".equals(typeKey)) {
                    List<Map<String, Object>> confListMap = (List) confContentMap.get(typeKey);
                    Iterator<Map<String, Object>> it = confListMap.iterator();
                    while (true) {
                        if (!it.hasNext()) {
                            break;
                        }
                        Map<String, Object> conf = it.next();
                        if (conf.containsKey("db")) {
                            if (idarr[2].equals(ObjectUtil.getString(conf.get("db"), ""))) {
                                confMap.putAll(conf);
                                break;
                            }
                        } else if (idarr[2].equals(ObjectUtil.getString(conf.get("linuxV"), ""))) {
                            confMap.putAll(conf);
                            break;
                        }
                    }
                } else {
                    confMap.putAll((Map) confContentMap.get(typeKey));
                }
                if (!ReportService.REPORT_STATE_FAILED.equals(typeKey) && authConfMap != null) {
                    confMap.putAll(authConfMap);
                }
                map.put("confContent", JsonUtil.MAPPER.writeValueAsString(confMap));
                if (ReportService.REPORT_STATE_READY.equals(typeKey)) {
                    typeKey = "7";
                } else if (ReportService.REPORT_STATE_FAILED.equals(typeKey)) {
                    typeKey = "8";
                }
                map.put("type", typeKey);
                map.put("name", ObjectUtil.getString(webMap.get("name"), ""));
                this.baselineMapper.insertTaskDevice(map);
                devices.add(ObjectUtil.getInt(map.get("id")));
            }
        }
        for (Integer devid : devices) {
            Map<String, Object> devMap = this.baselineMapper.getTaskDevById(devid);
            Task task = this.baselineMapper.getTaskById(taskId);
            if (task != null && task.getType().intValue() == 1) {
                User user = (User) session.getAttribute("userInfo");
                boolean bl = true;
                try {
                    start(ObjectUtil.getInt(devMap.get("id")));
                } catch (Exception e) {
                    bl = false;
                    this.LOG.error("扫描出错", e);
                }
                if (bl) {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描基线配置核查任务", "", 1, "扫描成功");
                } else {
                    this.logMapper.insert(user == null ? "未登录" : user.getName(), "开始扫描基线配置核查任务", "", 2, "扫描失败");
                }
            }
        }
    }

    public List<Map<String, Object>> getDevDetailByTid(Integer id) throws Exception {
        return this.baselineMapper.getDevDetailByTid(id);
    }

    public Map<String, Object> bugPie(Integer id) throws Exception {
        return this.baselineMapper.bugPie(id);
    }

    public List<Map<String, Object>> blineResult(Integer id, Integer offset, Integer limit) throws Exception {
        return this.baselineMapper.blineResult(id, offset, limit);
    }

    public List<Map<String, Object>> errByDevid(Integer id) throws Exception {
        return this.baselineMapper.errByDevid(id);
    }

    public Integer errCountByDevid(Integer id) throws Exception {
        return this.baselineMapper.errCountByDevid(id);
    }

    public Map<String, Object> getBugByIdAndType(Integer id, String type) throws Exception {
        return this.blineBugMapper.getBugByIdAndType(id, type);
    }

    private void delTask(HttpSession session, Integer id, Integer version) throws Exception {
        List<Map<String, Object>> devList = this.baselineMapper.getTaskDevByTid(id);
        Exception ex = null;
        int count = 0;
        for (Map<String, Object> dev : devList) {
            try {
                String engineId = ObjectUtil.getString(dev.get("engineId"), "");
                if (StringUtils.isNotBlank(engineId)) {
                    this.engine.blineDelete(ObjectUtil.getInt(dev.get("type"), -1), engineId, ObjectUtil.getInt(dev.get("localEid")).intValue());
                }
                count++;
            } catch (Exception e) {
                this.LOG.error("", e);
                ex = e;
            }
        }
        if (count == 0) {
            throw ex;
        }
        Iterator<Map<String, Object>> it = devList.iterator();
        while (it.hasNext()) {
            Integer did = ObjectUtil.getInt(it.next().get("id"));
            this.blineBugMapper.delResultByDevId(did);
            this.blineBugMapper.delResultByDevId2(did);
            this.blineBugMapper.delErr(did);
            this.blineBugMapper.clearStatistics(did);
        }
        stopTimer(session, id);
        this.baselineMapper.delTaskDevByTid(id);
        Integer rcount = Integer.valueOf(this.baselineMapper.delete(id, version, DataRule.getRuleWhere(session, "t_task")));
        if (rcount.intValue() == 0) {
            throw new UEException("数据已被修改或删除，请刷新页面或返回");
        }
    }

    public List<String> getBtype() throws Exception {
        return this.baselineMapper.getBtype();
    }

    public Integer blineResCount(Integer id) throws Exception {
        return this.baselineMapper.blineResCount(id);
    }

    public List<Map<String, Object>> blineBugForDevice(Integer id) throws Exception {
        return this.baselineMapper.blineBugForDevice(id);
    }

    public Map<String, Object> getBlineResById(String poliid, Integer deviceid, String type) throws Exception {
        return this.baselineMapper.getBlineResById(poliid, deviceid, type);
    }

    public static void main(String[] args) throws Exception {
        File winClient = new File(Constant.WORK_DIR, "tools/winClient.exe");
        File tmpFile = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        FileUtils.copyFile(winClient, tmpFile);
        List<String> ipList = IPUtil.getIpList();
        if (ipList.size() > 0) {
            FileOutputStream fos = null;
            try {
                fos = new FileOutputStream(tmpFile, true);
                String content = "https://" + ipList.get(0);
                byte[] bs = content.getBytes();
                fos.write(bs);
                fos.write(ObjectUtil.int2bytes(bs.length));
                fos.flush();
                IOUtils.closeQuietly(fos);
            } catch (Throwable th) {
                IOUtils.closeQuietly(fos);
                throw th;
            }
        }
    }

    public int markBugErr(Integer id, Integer status) throws Exception {
        return this.baselineMapper.markBugErr(id, status);
    }

    public int updBlineRes(String poliid, Integer value, Integer devid) throws Exception {
        return this.baselineMapper.updBlineRes(poliid, value, devid);
    }

    public File blineBackup(Task t) throws Exception {
        File dir = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        if (!dir.exists()) {
            dir.mkdirs();
        }
        File f = new File(Constant.TEMP_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        try {
            SerializeUtil.serializeObj(new File(dir, "task.backup"), t);
            List<Map<String, Object>> devList = this.baselineMapper.getTaskDevByTid(t.getId());
            for (Map<String, Object> dev : devList) {
                Integer devid = ObjectUtil.getInt(dev.get("id"));
                File devDir = new File(dir, new StringBuilder().append(devid).toString());
                if (!devDir.exists()) {
                    devDir.mkdirs();
                }
                SerializeUtil.serializeObj(new File(devDir, "dev.backup"), dev);
                SerializeUtil.serializeObj(new File(devDir, "bug.backup"), this.baselineMapper.getBugByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "bug2.backup"), this.baselineMapper.getBug2ByDevId(devid));
                SerializeUtil.serializeObj(new File(devDir, "sta.backup"), this.baselineMapper.getStaByDevId(devid));
            }
            ComonZipUtil.zip(dir.getPath(), f.getPath());
            if (dir != null && dir.exists()) {
                FileUtils.deleteDirectory(dir);
            }
            return f;
        } catch (Exception e) {
            throw e;
        }
    }

    @Transactional
    public void blineRestore(HttpSession session, File f) throws Exception {
        File unzipFile = new File(Constant.COMMON_DIR, new StringBuilder(String.valueOf(System.nanoTime())).toString());
        ComonZipUtil.unzip(f, unzipFile);
        File taskFile = new File(unzipFile, "task.backup");
        Task t = (Task) SerializeUtil.deserializeObj(taskFile);
        Integer uid = ((User) session.getAttribute("userInfo")).getId();
        Integer count = this.baselineMapper.getTaskCountByName(t.getName(), 2, uid, (Integer) null);
        if (count != null && count.intValue() > 0) {
            throw new UEException("blineTaskAlready:" + unzipFile.getName());
        }
        try {
            restore(unzipFile, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(unzipFile);
            throw e;
        }
    }

    private void restore(File unzipFile, Task t) throws Exception {
        Map<String, Object> device;
        if (unzipFile == null || t == null) {
            return;
        }
        this.baselineMapper.insert(t);
        for (File taskDir : unzipFile.listFiles()) {
            if (!taskDir.getName().equals("task.backup") && (device = (Map) SerializeUtil.deserializeObj(new File(taskDir, "dev.backup"))) != null && device.size() != 0) {
                device.put("taskId", t.getId());
                this.baselineMapper.inserTaskDevById(device);
                Integer devId = ObjectUtil.getInt(device.get("id"));
                List<Map<String, Object>> bugs = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug.backup"));
                if (bugs != null && bugs.size() > 0) {
                    this.baselineMapper.insertBlineRes(devId, bugs);
                }
                List<Map<String, Object>> bugs2 = (List) SerializeUtil.deserializeObj(new File(taskDir, "bug2.backup"));
                if (bugs2 != null && bugs2.size() > 0) {
                    this.baselineMapper.insertBlineRes2(devId, bugs2);
                }
                List<Map<String, Object>> stas = (List) SerializeUtil.deserializeObj(new File(taskDir, "sta.backup"));
                if (stas != null && stas.size() > 0) {
                    this.baselineMapper.inserBlineSta(devId, stas);
                }
            }
        }
        startTimer(t.getId(), t.getType(), t.getPeriodTime(), t.getAlarmType(), t.getAlarmMethod(), t.getAlarmTime());
        FileUtils.deleteDirectory(unzipFile);
    }

    @Transactional
    public void blineEnter(HttpSession session, String filename) throws Exception {
        File f = new File(Constant.COMMON_DIR, filename);
        if (f == null || !f.exists()) {
            this.LOG.error("基线恢复，文件不存在！");
            return;
        }
        User u = (User) session.getAttribute("userInfo");
        Task t = (Task) SerializeUtil.deserializeObj(new File(f, "task.backup"));
        t.setName(String.valueOf(t.getName()) + System.nanoTime());
        t.setUid(u.getId());
        try {
            restore(f, t);
        } catch (Exception e) {
            FileUtils.deleteDirectory(f);
            throw e;
        }
    }

    public List<Map<String, Object>> blineSpResult(Integer id) {
        return this.baselineMapper.blineSpResult(id);
    }

    public List<Map<String, Object>> blineResultInter(Integer id) throws Exception {
        return this.baselineMapper.blineResultInter(id);
    }

    public List<Map<String, Object>> getPnameByType(String type) throws Exception {
        return this.baselineMapper.getPnameByType(type);
    }
}
